GroupFn

Type Alias GroupFn 

pub(crate) type GroupFn = dyn Fn(&Object, &Object) -> bool;
A function to determine if an item should be grouped with another contiguous item.

This function MUST always return true when used with any two items in the same group.